Crate perl_module_token_parser

Crate perl_module_token_parser 

Single-line Perl module token parsing.

This microcrate has one responsibility: parse Perl package-style tokens from byte offsets in a source line. It supports canonical (::) and legacy (') package separators.

Structs

ModuleTokenSpan
Byte span for a parsed module token.

Functions

parse_module_token
Parse a module token that starts at start in text.